==> lambdastepfunctions-1.115.0-sources.jar: software/amazon/awsconstructs/services/lambdastepfunctions/LambdaToStepfunctionsProps.java <==
package software.amazon.awsconstructs.services.lambdastepfunctions;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.32.0 (build 3f4fe23)", date = "2021-08-11T23:45:36.110Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdastepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctionsProps")
@software.amazon.jsii.Jsii.Proxy(LambdaToStepfunctionsProps.Jsii$Proxy.class)
public interface LambdaToStepfunctionsProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * User provided StateMachineProps to override the defaults.
     * <p>
     * Default: - None
     */
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachineProps getStateMachineProps();

    /**
     * Whether to create recommended CloudWatch alarms.
     * <p>
     * Default: - Alarms are created
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getCreateCloudWatchAlarms() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default properties are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * User provided props to override the default props for the CloudWatchLogs LogGroup.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.logs.LogGroupProps getLogGroupProps() {
        return null;
    }

    /**
     * Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable java.lang.String getStateMachineEnvironmentVariableName() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaToStepfunctionsProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaToStepfunctionsProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<LambdaToStepfunctionsProps> {
        private software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps;
        private java.lang.Boolean createCloudWatchAlarms;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private software.amazon.awscdk.services.logs.LogGroupProps logGroupProps;
        private java.lang.String stateMachineEnvironmentVariableName;

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getStateMachineProps}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         * @return {@code this}
         */
        public Builder stateMachineProps(software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.stateMachineProps = stateMachineProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getCreateCloudWatchAlarms}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms.
         * @return {@code this}
         */
        public Builder createCloudWatchAlarms(java.lang.Boolean createCloudWatchAlarms) {
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getLogGroupProps}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup.
         * @return {@code this}
         */
        public Builder logGroupProps(software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.logGroupProps = logGroupProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getStateMachineEnvironmentVariableName}
         * @param stateMachineEnvironmentVariableName Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
         * @return {@code this}
         */
        public Builder stateMachineEnvironmentVariableName(java.lang.String stateMachineEnvironmentVariableName) {
            this.stateMachineEnvironmentVariableName = stateMachineEnvironmentVariableName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaToStepfunctionsProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public LambdaToStepfunctionsProps build() {
            return new Jsii$Proxy(stateMachineProps, createCloudWatchAlarms, existingLambdaObj, lambdaFunctionProps, logGroupProps, stateMachineEnvironmentVariableName);
        }
    }

    /**
     * An implementation for {@link LambdaToStepfunctionsProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaToStepfunctionsProps {
        private final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps;
        private final java.lang.Boolean createCloudWatchAlarms;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps;
        private final java.lang.String stateMachineEnvironmentVariableName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.stateMachineProps = software.amazon.jsii.Kernel.get(this, "stateMachineProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachineProps.class));
            this.createCloudWatchAlarms = software.amazon.jsii.Kernel.get(this, "createCloudWatchAlarms", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.existingLambdaObj = software.amazon.jsii.Kernel.get(this, "existingLambdaObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
            this.lambdaFunctionProps = software.amazon.jsii.Kernel.get(this, "lambdaFunctionProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.FunctionProps.class));
            this.logGroupProps = software.amazon.jsii.Kernel.get(this, "logGroupProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroupProps.class));
            this.stateMachineEnvironmentVariableName = software.amazon.jsii.Kernel.get(this, "stateMachineEnvironmentVariableName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps, final java.lang.Boolean createCloudWatchAlarms, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps, final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps, final java.lang.String stateMachineEnvironmentVariableName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.stateMachineProps = java.util.Objects.requireNonNull(stateMachineProps, "stateMachineProps is required");
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            this.existingLambdaObj = existingLambdaObj;
            this.lambdaFunctionProps = lambdaFunctionProps;
            this.logGroupProps = logGroupProps;
            this.stateMachineEnvironmentVariableName = stateMachineEnvironmentVariableName;
        }

        @Override
        public final software.amazon.awscdk.services.stepfunctions.StateMachineProps getStateMachineProps() {
            return this.stateMachineProps;
        }

        @Override
        public final java.lang.Boolean getCreateCloudWatchAlarms() {
            return this.createCloudWatchAlarms;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public final software.amazon.awscdk.services.logs.LogGroupProps getLogGroupProps() {
            return this.logGroupProps;
        }

        @Override
        public final java.lang.String getStateMachineEnvironmentVariableName() {
            return this.stateMachineEnvironmentVariableName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("stateMachineProps", om.valueToTree(this.getStateMachineProps()));
            if (this.getCreateCloudWatchAlarms() != null) {
                data.set("createCloudWatchAlarms", om.valueToTree(this.getCreateCloudWatchAlarms()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }
            if (this.getLogGroupProps() != null) {
                data.set("logGroupProps", om.valueToTree(this.getLogGroupProps()));
            }
            if (this.getStateMachineEnvironmentVariableName() != null) {
                data.set("stateMachineEnvironmentVariableName", om.valueToTree(this.getStateMachineEnvironmentVariableName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctionsProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaToStepfunctionsProps.Jsii$Proxy that = (LambdaToStepfunctionsProps.Jsii$Proxy) o;

            if (!stateMachineProps.equals(that.stateMachineProps)) return false;
            if (this.createCloudWatchAlarms != null ? !this.createCloudWatchAlarms.equals(that.createCloudWatchAlarms) : that.createCloudWatchAlarms != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            if (this.lambdaFunctionProps != null ? !this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps != null) return false;
            if (this.logGroupProps != null ? !this.logGroupProps.equals(that.logGroupProps) : that.logGroupProps != null) return false;
            return this.stateMachineEnvironmentVariableName != null ? this.stateMachineEnvironmentVariableName.equals(that.stateMachineEnvironmentVariableName) : that.stateMachineEnvironmentVariableName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.stateMachineProps.hashCode();
            result = 31 * result + (this.createCloudWatchAlarms != null ? this.createCloudWatchAlarms.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            result = 31 * result + (this.logGroupProps != null ? this.logGroupProps.hashCode() : 0);
            result = 31 * result + (this.stateMachineEnvironmentVariableName != null ? this.stateMachineEnvironmentVariableName.hashCode() : 0);
            return result;
        }
    }
}

==> lambdastepfunctions-1.119.0-sources.jar: software/amazon/awsconstructs/services/lambdastepfunctions/LambdaToStepfunctionsProps.java <==
package software.amazon.awsconstructs.services.lambdastepfunctions;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-02T18:45:35.353Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdastepfunctions.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctionsProps")
@software.amazon.jsii.Jsii.Proxy(LambdaToStepfunctionsProps.Jsii$Proxy.class)
public interface LambdaToStepfunctionsProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * User provided StateMachineProps to override the defaults.
     * <p>
     * Default: - None
     */
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StateMachineProps getStateMachineProps();

    /**
     * Whether to create recommended CloudWatch alarms.
     * <p>
     * Default: - Alarms are created
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getCreateCloudWatchAlarms() {
        return null;
    }

    /**
     * Whether to deploy a new VPC.
     * <p>
     * Default: - false
     */
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getDeployVpc() {
        return null;
    }

    /**
     * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
        return null;
    }

    /**
     * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getExistingVpc() {
        return null;
    }

    /**
     * User provided props to override the default props for the Lambda function.
     * <p>
     * Default: - Default properties are used.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
        return null;
    }

    /**
     * User provided props to override the default props for the CloudWatchLogs LogGroup.
     * <p>
     * Default: - Default props are used
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.logs.LogGroupProps getLogGroupProps() {
        return null;
    }

    /**
     * Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
     * <p>
     * Default: - None
     */
    default @org.jetbrains.annotations.Nullable java.lang.String getStateMachineEnvironmentVariableName() {
        return null;
    }

    /**
     * Properties to override default properties if deployVpc is true.
     */
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.VpcProps getVpcProps() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaToStepfunctionsProps}
     */
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaToStepfunctionsProps}
     */
    public static final class Builder implements software.amazon.jsii.Builder<LambdaToStepfunctionsProps> {
        private software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps;
        private java.lang.Boolean createCloudWatchAlarms;
        private java.lang.Boolean deployVpc;
        private software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private software.amazon.awscdk.services.ec2.IVpc existingVpc;
        private software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private software.amazon.awscdk.services.logs.LogGroupProps logGroupProps;
        private java.lang.String stateMachineEnvironmentVariableName;
        private software.amazon.awscdk.services.ec2.VpcProps vpcProps;

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getStateMachineProps}
         * @param stateMachineProps User provided StateMachineProps to override the defaults. This parameter is required.
         * @return {@code this}
         */
        public Builder stateMachineProps(software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps) {
            this.stateMachineProps = stateMachineProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getCreateCloudWatchAlarms}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms.
         * @return {@code this}
         */
        public Builder createCloudWatchAlarms(java.lang.Boolean createCloudWatchAlarms) {
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getDeployVpc}
         * @param deployVpc Whether to deploy a new VPC.
         * @return {@code this}
         */
        public Builder deployVpc(java.lang.Boolean deployVpc) {
            this.deployVpc = deployVpc;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getExistingLambdaObj}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * @return {@code this}
         */
        public Builder existingLambdaObj(software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.existingLambdaObj = existingLambdaObj;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getExistingVpc}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * @return {@code this}
         */
        public Builder existingVpc(software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.existingVpc = existingVpc;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getLambdaFunctionProps}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function.
         * @return {@code this}
         */
        public Builder lambdaFunctionProps(software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.lambdaFunctionProps = lambdaFunctionProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getLogGroupProps}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup.
         * @return {@code this}
         */
        public Builder logGroupProps(software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.logGroupProps = logGroupProps;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getStateMachineEnvironmentVariableName}
         * @param stateMachineEnvironmentVariableName Optional Name for the Step Functions state machine environment variable set for the producer Lambda function.
         * @return {@code this}
         */
        public Builder stateMachineEnvironmentVariableName(java.lang.String stateMachineEnvironmentVariableName) {
            this.stateMachineEnvironmentVariableName = stateMachineEnvironmentVariableName;
            return this;
        }

        /**
         * Sets the value of {@link LambdaToStepfunctionsProps#getVpcProps}
         * @param vpcProps Properties to override default properties if deployVpc is true.
         * @return {@code this}
         */
        public Builder vpcProps(software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.vpcProps = vpcProps;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaToStepfunctionsProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @Override
        public LambdaToStepfunctionsProps build() {
            return new Jsii$Proxy(stateMachineProps, createCloudWatchAlarms, deployVpc, existingLambdaObj, existingVpc, lambdaFunctionProps, logGroupProps, stateMachineEnvironmentVariableName, vpcProps);
        }
    }

    /**
     * An implementation for {@link LambdaToStepfunctionsProps}
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaToStepfunctionsProps {
        private final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps;
        private final java.lang.Boolean createCloudWatchAlarms;
        private final java.lang.Boolean deployVpc;
        private final software.amazon.awscdk.services.lambda.Function existingLambdaObj;
        private final software.amazon.awscdk.services.ec2.IVpc existingVpc;
        private final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps;
        private final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps;
        private final java.lang.String stateMachineEnvironmentVariableName;
        private final software.amazon.awscdk.services.ec2.VpcProps vpcProps;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.stateMachineProps = software.amazon.jsii.Kernel.get(this, "stateMachineProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StateMachineProps.class));
            this.createCloudWatchAlarms = software.amazon.jsii.Kernel.get(this, "createCloudWatchAlarms", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.deployVpc = software.amazon.jsii.Kernel.get(this, "deployVpc", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.existingLambdaObj = software.amazon.jsii.Kernel.get(this, "existingLambdaObj", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
            this.existingVpc = software.amazon.jsii.Kernel.get(this, "existingVpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
            this.lambdaFunctionProps = software.amazon.jsii.Kernel.get(this, "lambdaFunctionProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.FunctionProps.class));
            this.logGroupProps = software.amazon.jsii.Kernel.get(this, "logGroupProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroupProps.class));
            this.stateMachineEnvironmentVariableName = software.amazon.jsii.Kernel.get(this, "stateMachineEnvironmentVariableName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.vpcProps = software.amazon.jsii.Kernel.get(this, "vpcProps", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.VpcProps.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.stepfunctions.StateMachineProps stateMachineProps, final java.lang.Boolean createCloudWatchAlarms, final java.lang.Boolean deployVpc, final software.amazon.awscdk.services.lambda.Function existingLambdaObj, final software.amazon.awscdk.services.ec2.IVpc existingVpc, final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps, final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps, final java.lang.String stateMachineEnvironmentVariableName, final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.stateMachineProps = java.util.Objects.requireNonNull(stateMachineProps, "stateMachineProps is required");
            this.createCloudWatchAlarms = createCloudWatchAlarms;
            this.deployVpc = deployVpc;
            this.existingLambdaObj = existingLambdaObj;
            this.existingVpc = existingVpc;
            this.lambdaFunctionProps = lambdaFunctionProps;
            this.logGroupProps = logGroupProps;
            this.stateMachineEnvironmentVariableName = stateMachineEnvironmentVariableName;
            this.vpcProps = vpcProps;
        }

        @Override
        public final software.amazon.awscdk.services.stepfunctions.StateMachineProps getStateMachineProps() {
            return this.stateMachineProps;
        }

        @Override
        public final java.lang.Boolean getCreateCloudWatchAlarms() {
            return this.createCloudWatchAlarms;
        }

        @Override
        public final java.lang.Boolean getDeployVpc() {
            return this.deployVpc;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.Function getExistingLambdaObj() {
            return this.existingLambdaObj;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.IVpc getExistingVpc() {
            return this.existingVpc;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.FunctionProps getLambdaFunctionProps() {
            return this.lambdaFunctionProps;
        }

        @Override
        public final software.amazon.awscdk.services.logs.LogGroupProps getLogGroupProps() {
            return this.logGroupProps;
        }

        @Override
        public final java.lang.String getStateMachineEnvironmentVariableName() {
            return this.stateMachineEnvironmentVariableName;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.VpcProps getVpcProps() {
            return this.vpcProps;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("stateMachineProps", om.valueToTree(this.getStateMachineProps()));
            if (this.getCreateCloudWatchAlarms() != null) {
                data.set("createCloudWatchAlarms", om.valueToTree(this.getCreateCloudWatchAlarms()));
            }
            if (this.getDeployVpc() != null) {
                data.set("deployVpc", om.valueToTree(this.getDeployVpc()));
            }
            if (this.getExistingLambdaObj() != null) {
                data.set("existingLambdaObj", om.valueToTree(this.getExistingLambdaObj()));
            }
            if (this.getExistingVpc() != null) {
                data.set("existingVpc", om.valueToTree(this.getExistingVpc()));
            }
            if (this.getLambdaFunctionProps() != null) {
                data.set("lambdaFunctionProps", om.valueToTree(this.getLambdaFunctionProps()));
            }
            if (this.getLogGroupProps() != null) {
                data.set("logGroupProps", om.valueToTree(this.getLogGroupProps()));
            }
            if (this.getStateMachineEnvironmentVariableName() != null) {
                data.set("stateMachineEnvironmentVariableName", om.valueToTree(this.getStateMachineEnvironmentVariableName()));
            }
            if (this.getVpcProps() != null) {
                data.set("vpcProps", om.valueToTree(this.getVpcProps()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctionsProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaToStepfunctionsProps.Jsii$Proxy that = (LambdaToStepfunctionsProps.Jsii$Proxy) o;

            if (!stateMachineProps.equals(that.stateMachineProps)) return false;
            if (this.createCloudWatchAlarms != null ? !this.createCloudWatchAlarms.equals(that.createCloudWatchAlarms) : that.createCloudWatchAlarms != null) return false;
            if (this.deployVpc != null ? !this.deployVpc.equals(that.deployVpc) : that.deployVpc != null) return false;
            if (this.existingLambdaObj != null ? !this.existingLambdaObj.equals(that.existingLambdaObj) : that.existingLambdaObj != null) return false;
            if (this.existingVpc != null ? !this.existingVpc.equals(that.existingVpc) : that.existingVpc != null) return false;
            if (this.lambdaFunctionProps != null ? !this.lambdaFunctionProps.equals(that.lambdaFunctionProps) : that.lambdaFunctionProps != null) return false;
            if (this.logGroupProps != null ? !this.logGroupProps.equals(that.logGroupProps) : that.logGroupProps != null) return false;
            if (this.stateMachineEnvironmentVariableName != null ? !this.stateMachineEnvironmentVariableName.equals(that.stateMachineEnvironmentVariableName) : that.stateMachineEnvironmentVariableName != null) return false;
            return this.vpcProps != null ? this.vpcProps.equals(that.vpcProps) : that.vpcProps == null;
        }

        @Override
        public final int hashCode() {
            int result = this.stateMachineProps.hashCode();
            result = 31 * result + (this.createCloudWatchAlarms != null ? this.createCloudWatchAlarms.hashCode() : 0);
            result = 31 * result + (this.deployVpc != null ? this.deployVpc.hashCode() : 0);
            result = 31 * result + (this.existingLambdaObj != null ? this.existingLambdaObj.hashCode() : 0);
            result = 31 * result + (this.existingVpc != null ? this.existingVpc.hashCode() : 0);
            result = 31 * result + (this.lambdaFunctionProps != null ? this.lambdaFunctionProps.hashCode() : 0);
            result = 31 * result + (this.logGroupProps != null ? this.logGroupProps.hashCode() : 0);
            result = 31 * result + (this.stateMachineEnvironmentVariableName != null ? this.stateMachineEnvironmentVariableName.hashCode() : 0);
            result = 31 * result + (this.vpcProps != null ? this.vpcProps.hashCode() : 0);
            return result;
        }
    }
}
